==> spring-boot-ext-1.2.279.1-sources.jar: cn/com/duibaboot/ext/autoconfigure/flowreplay/RedisFlowReplaySpan.java <==
package cn.com.duibaboot.ext.autoconfigure.flowreplay;

import cn.com.duiba.wolf.utils.UUIDUtils;
import cn.com.duibaboot.ext.autoconfigure.flowreplay.serializer.KryoSerializer;

import java.lang.reflect.Method;

/**
 * redis调用的span
 * Created by guoyanfei .
 * 2019-02-15 .
 */
public class RedisFlowReplaySpan extends FlowReplaySpan {

    private static final long serialVersionUID = -806469460614892717L;

    /**
     * 方法名称
     */
    private String methodName;

    /**
     * 参数类型数组
     */
    private String[] parameterTypes;

    /**
     * 参数值数组
     */
    private byte[] parameterValues;

    /**
     * 返回值
     */
    private byte[] returnValue;

    @Override
    public SpanType getSpanType() {
        return SpanType.REDIS;
    }

    /**
     * 创建span
     * @param method
     * @param allArguments
     * @param argumentsTypes
     * @param ret
     * @return
     */
    public static RedisFlowReplaySpan createSpan(Method method, Object[] allArguments, Class<?>[] argumentsTypes, Object ret) {
        String[] parameterTypes = null;
        if (argumentsTypes.length > 0) {
            parameterTypes = new String[argumentsTypes.length];
            for (int i = 0; i < argumentsTypes.length; i++) {
                parameterTypes[i] = argumentsTypes[i].getName();
            }
        }
        RedisFlowReplaySpan span = new RedisFlowReplaySpan();
        span.setSpanId(UUIDUtils.createUUID());
        span.methodName = method.getName();
        span.parameterTypes = parameterTypes;
        span.parameterValues = KryoSerializer.serialize(allArguments);
        span.returnValue = KryoSerializer.serialize(ret);
        return span;
    }

    public String getMethodName() {
        return methodName;
    }

    public String[] getParameterTypes() {
        return parameterTypes;
    }

    public Object[] getParameterValues() {
        return (Object[]) KryoSerializer.deserialize(parameterValues);
    }

    public Object getReturnValue() {
        return KryoSerializer.deserialize(returnValue);
    }
}

==> spring-boot-ext-1.2.289.3-sources.jar: cn/com/duibaboot/ext/autoconfigure/flowreplay/RedisFlowReplaySpan.java <==
package cn.com.duibaboot.ext.autoconfigure.flowreplay;

import cn.com.duiba.wolf.utils.UUIDUtils;
import cn.com.duibaboot.ext.autoconfigure.flowreplay.serializer.KryoSerializer;

import java.lang.reflect.Method;

/**
 * redis调用的span
 * Created by guoyanfei .
 * 2019-02-15 .
 */
public class RedisFlowReplaySpan extends FlowReplaySpan {

    private static final long serialVersionUID = -806469460614892717L;

    /**
     * 方法名称
     */
    private String methodName;

    /**
     * 参数类型数组
     */
    private String[] parameterTypes;

    /**
     * 参数值数组
     */
    private byte[] parameterValues;

    /**
     * 返回值
     */
    private byte[] returnValue;

    @Override
    public SpanType getSpanType() {
        return SpanType.REDIS;
    }

    /**
     * 创建span
     * @param method
     * @param allArguments
     * @param argumentsTypes
     * @param ret
     * @return
     */
    public static RedisFlowReplaySpan createSpan(Method method, Object[] allArguments, Class<?>[] argumentsTypes, Object ret) {
        String[] parameterTypes = null;
        if (argumentsTypes != null && argumentsTypes.length > 0) {
            parameterTypes = new String[argumentsTypes.length];
            for (int i = 0; i < argumentsTypes.length; i++) {
                parameterTypes[i] = argumentsTypes[i].getName();
            }
        }
        RedisFlowReplaySpan span = new RedisFlowReplaySpan();
        span.setSpanId(UUIDUtils.createUUID());
        span.methodName = method.getName();
        span.parameterTypes = parameterTypes;
        span.parameterValues = KryoSerializer.serialize(allArguments);
        span.returnValue = KryoSerializer.serialize(ret);
        return span;
    }

    public String getMethodName() {
        return methodName;
    }

    public String[] getParameterTypes() {
        return parameterTypes;
    }

    public Object[] getParameterValues() {
        return (Object[]) KryoSerializer.deserialize(parameterValues);
    }

    public Object getReturnValue() {
        return KryoSerializer.deserialize(returnValue);
    }
}
